@@ -18,7 +18,9 @@ my $args = {
 
 my $enigma = Crypt::Enigma->new( $args );
 
-$enigma->setSteckerBoard( [ 'G', 'C' ] );
+$enigma->setDebug( 1 );
+
+$enigma->setSteckerBoard( [ 'G' ] );
 
 print "Plain text:\t$text\n";
 print "Cipher Text:\t", $enigma->cipher( $text ), " \n";
